Changelog
=========


(unreleased)
------------
- Make packages explicit in setup. [Max Parzen]


0.0.4 (2022-12-31)
------------------
- Release: version 0.0.4 🚀 [Max Parzen]
- Add requirements to manifest. [Max Parzen]


0.0.3 (2022-12-31)
------------------
- Release: version 0.0.3 🚀 [Max Parzen]
- Release: version 0.0.2 🚀 [Max Parzen]
- Remove for now docker file (#24) [Max Parzen]
- Small path fix. [mnm-matin]
- Add whitespace. [mnm-matin]
- Disable CI for mac and windows. [mnm-matin]
- Add docstrings for filter_pbf. [mnm-matin]
- Revert "lint code (#22)" [mnm-matin]

  This reverts commit 0c5388e8cd0d82c185a44aa4a50fba76a9419c14.
- Revert "release 0.0.2 (#23)" [mnm-matin]

  This reverts commit 8a1ee61c4a6f39770d24b7f9b2d60c96e617bc45.


0.0.2 (2022-12-30)
------------------
- Release 0.0.2 (#23) [Max Parzen]
- Lint code (#22) [Max Parzen]
- Add docs and classifiers to setup. [Max Parzen]
- Update README.md. [Max Parzen]
- Update setup.py. [Max Parzen]
- Merge branch 'main' of https://github.com/pypsa-meets-africa/earth-osm
  into main. [mnm-matin]
- Update README.md. [Max Parzen]
- Add badges (#21) [Max Parzen]

  * add badges

  * rename header
- Pin mypy version. [mnm-matin]
- Contrib add docs update. [mnm-matin]
- Add codecov badge. [mnm-matin]
- Add test tot makefile. [mnm-matin]
- Add test. [mnm-matin]
- Enable tests and code cov. [mnm-matin]
- Add CI badge. [mnm-matin]
- Add development notes to README. [mnm-matin]
- Remove f string. [mnm-matin]
- Add make release to make file. [mnm-matin]
- Add release instruction. [mnm-matin]


0.0.1 (2022-12-30)
------------------
- Release: version 0.0.1 🚀 [mnm-matin]
- Merge pull request #20 from pz-max/cat. [Matin Mahmood]

  add aggregate option and output format choice
- Fixes n roll. [Max Parzen]
- Add aggregate option and output format choice. [Max Parzen]
- Add MANIFEST.in and History.md. [mnm-matin]
- Add pypi release workkflow. [mnm-matin]
- Merge pull request #19 from pz-max/main. [Matin Mahmood]

  fix encoding bug
- Fix encoding bug. [Max Parzen]
- Merge pull request #17 from pypsa-meets-earth/pz-max-patch-1. [Matin
  Mahmood]

  area crs correction and documentation
- Area crs correction and documentation. [Max Parzen]
- Disable tests from CI. [mnm-matin]
- Add CI test without linter. [mnm-matin]
- Merge pull request #2 from pz-max/rename-africa. [Matin Mahmood]

  rename africa to earth
- Rename africa to earth. [Max Parzen]
- Improve readability. [mnm-matin]
- Merge branch 'main' of https://github.com/pypsa-meets-africa/earth-osm
  into main. [mnm-matin]
- Update README.md. [Matin Mahmood]
- Update README.md. [Matin Mahmood]
- Requirements specify version for protobuf. [mnm-matin]
- Add contributing guide. [mnm-matin]
- Pull Request Template. [mnm-matin]
- Feature request template. [mnm-matin]
- Add bug_report template. [mnm-matin]
- Add docker containerfile. [mnm-matin]
- Make docs. [mnm-matin]
- Make virtualenv. [mnm-matin]
- Make clean. [mnm-matin]
- Add linting. [mnm-matin]
- Add formatting. [mnm-matin]
- Make install Makefile. [mnm-matin]
- Generate lazydocs api docs. [mnm-matin]
- Docs index. [mnm-matin]
- Add mkdocs config. [mnm-matin]
- Header. [mnm-matin]
- Advanced usage instructions. [mnm-matin]
- Args explained. [mnm-matin]
- Extract readme. [mnm-matin]
- Getting started readme. [mnm-matin]
- Setup tools and requirements. [mnm-matin]
- Add version file package. [mnm-matin]
- Initialize test module. [mnm-matin]
- Misc argparser notes. [mnm-matin]
- Version arg for test. [mnm-matin]
- Help arg and subparser helper. [mnm-matin]
- Add earth_osm print. [mnm-matin]
- Add not implemented interactive parser. [mnm-matin]
- Exeecute get_osm_data. [mnm-matin]
- Verbose print args. [mnm-matin]
- Verify data args. [mnm-matin]
- Verify feature args. [mnm-matin]
- Not implemented coord args. [mnm-matin]
- Region arg logic. [mnm-matin]
- Print regions. [mnm-matin]
- Parse args. [mnm-matin]
- View type arg. [mnm-matin]
- Sub parser view. [mnm-matin]
- Extract data_dir arg. [mnm-matin]
- Extract mp arg. [mnm-matin]
- Extract update arg. [mnm-matin]
- Extract feature arg. [mnm-matin]
- Extract region list arg. [mnm-matin]
- Add extract primary arg. [mnm-matin]
- Add basic argparser. [mnm-matin]
- Finalize base executer function. [mnm-matin]
- Add function rename todo. [mnm-matin]
- Csv and geojson emitter. [mnm-matin]
- Conv pd to gdf lines. [mnm-matin]
- Conv pd to gdf nodes. [mnm-matin]
- Add earth_osm region processor. [mnm-matin]
- Convert ways to lines. [mnm-matin]
- Conv ways to points. [mnm-matin]
- Lonlat lookup. [mnm-matin]
- Filtered data wrapper. [mnm-matin]
- Primary dict filter. [mnm-matin]
- Add filter runner. [mnm-matin]
- Filter primary data. [mnm-matin]
- Add feature filter header. [mnm-matin]
- Add osm config. [mnm-matin]
- Add extract script header. [mnm-matin]
- Add multiprocessing supported primary filter. [mnm-matin]
- Commands for generating latest protoc file. [mnm-matin]
- How to install protoc. [mnm-matin]
- Osm proto compile instructions. [mnm-matin]
- Add proto files to gitignore. [mnm-matin]
- Add osmpbf file script header. [mnm-matin]
- Add osmpbf filereader. [mnm-matin]
- Generate latest protocol buffer. [mnm-matin]
- Add relation namedtuple. [mnm-matin]
- Add way namedtuple. [mnm-matin]
- Add Node namedtuple. [mnm-matin]
- Initialize osmpbf module. [mnm-matin]
- Region tuple docstring. [mnm-matin]
- Region tuple getter. [mnm-matin]
- Id by string docstrings. [mnm-matin]
- Id by string getter. [mnm-matin]
- Code by id docstring. [mnm-matin]
- Code by id getter. [mnm-matin]
- Id_by_code docstring. [mnm-matin]
- Get id by using code. [mnm-matin]
- Add region dict getter. [mnm-matin]
- View_region doc strings. [mnm-matin]
- View region function. [mnm-matin]
- Add all region doc srings. [mnm-matin]
- Add all region dict getter. [mnm-matin]
- Add valid list function. [mnm-matin]
- Add root list function. [mnm-matin]
- Add support for geometric sitemap. [mnm-matin]
- Add short_code to sitemap df. [mnm-matin]
- Download sitemap. [mnm-matin]
- Add gfk_data header. [mnm-matin]
- Add misc download verify code. [mnm-matin]
- Add update param todo. [mnm-matin]
- Add sitemap downloader. [mnm-matin]
- Add multi-download todo. [mnm-matin]
- Add earth_downloader docstrings. [mnm-matin]
- Add earth_downloader function. [mnm-matin]
- Gfk_download header. [mnm-matin]
- Add args entry point header. [mnm-matin]
- Set earth_osm entry point. [mnm-matin]
- Initialize python project. [mnm-matin]
- Add YEAR and PyPSA-meets-Earth. [mnm-matin]
- Add MIT LICENSE. [mnm-matin]
- Gitignore misc. [mnm-matin]
- Gitingore docs. [mnm-matin]
- Gitignore environments. [mnm-matin]
- Gitignore unit tests. [mnm-matin]
- Gitingore py package files. [mnm-matin]
- Gitignore py files. [mnm-matin]
- Gitignore external data dir. [mnm-matin]
- Gitignore internal dir. [mnm-matin]


